!make_step.


/*
	Reaction on perception of the new position of the agent. 
	
	Simply updates the agent's belief about its own position and the
	current step number.
*/
+!perceive_mypos(X,Y,Step)
	: mypos(X,Y,Step)
	<-	-mypos(X,Y,Step);
		-+step(Step);
		-+at(X,Y);
		.print("position and step updated: ",X, ",", Y, "-", Step).

/*
	Reaction on perception of a new cell content.
	
	Updates the agent's internal map representation and 
	removes the perception from the belief base.
*/
+!perceive_see(X,Y,Content,Step)
	: see(X,Y,Content,Step) & at(MyX,MyY)
	<-	-see(X,Y,Content,Step);
		AbsX = MyX + X;
		AbsY = MyY + Y;
		// in the case you want to use Java map representation, use this internal action 
		//jia.setPos(AbsX, AbsY, Content);
		.print("map position updated: pos(",AbsX,",",AbsY,",",Content,")").
		


/*
	Two rules handling perception updates.
*/
+!update_mypos
	: 	mypos(X,Y,Step)
	<-	!perceive_mypos(X,Y,_); !update_mypos.

+!update_see
	: 	see(X,Y,Content,Step)
	<-	!perceive_see(X,Y,_,_); !update_see.

/*
	Two rules handling finished perception cycles.
*/
-!update_mypos
	:	~mypos(_,_,_)
	<-	+perceived(mypos);
		!!make_step.

-!update_see
	:	~see(_,_,_,_)
	<- +perceived(see);
		!!make_step.

/*
	Implementation of the deliberation cycle. 
	
	Basically invocation of the perception processing and doing an action.
*/
+!make_step
	: 	perceived(mypos) & perceived(see)
	<-	-perceived(mypos);	// reset
		-perceived(see);	// reset
		// perceptions are processed -> do an action
		go(north);
		!!make_step.
	
/*
	Keeping the agent deliberation cycle alive.
	
	The deliberation cycle works only when there is an event to process. This 
	event is the main driver of the agent. It serves to force the agent to 
	process all the perceptions.
*/
+!make_step 
	: true 
	<-	!!update_mypos; 
		!!update_see; 
		!make_step.

