package arch;

import static jason.asSyntax.ASSyntax.createLiteral;
import static jason.asSyntax.ASSyntax.createNumber;
import static jason.asSyntax.ASSyntax.createString;

import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;

import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

import massim.agent.framework.AbstractAgent;
import massim.agent.framework.MessageContent;

import jason.JasonException;
import jason.architecture.AgArch;
import jason.asSemantics.ActionExec;
import jason.asSemantics.Message;
import jason.asSyntax.Literal;
import jason.asSyntax.StringTermImpl;
import jason.mas2j.ClassParameters;
import jason.runtime.Settings;

public class MasSimACArchitecture extends AgArch {
	/**
	 * link to MasSim agent
	 */
	private AbstractAgent massimAgent = null;
	
	/**
	 * Inbox queue for incoming messages
	 */
	private LinkedList<MessageContent> inbox = new LinkedList<MessageContent>();
	
	/**
	 * List of perceptions from the environment
	 */
	private List<Literal> percepts = new ArrayList<Literal>();
	

	@Override
	public void initAg(String agClass, ClassParameters bbPars, String asSrc,
			Settings stts) throws JasonException {		
		super.initAg(agClass, bbPars, asSrc, stts);
		
		String username = stts.getUserParameter("username");
        if (username.startsWith("\"")) username = username.substring(1,username.length()-1);
        username = username.replaceAll("#nid", ""+(getAgId(getAgName())+1));
		
        String password = stts.getUserParameter("password");
        if (password.startsWith("\"")) password = password.substring(1,password.length()-1);

        
        massimAgent = new massim.agent.implementation.ExampleAgent(username, password, this);
        
		Thread thread = new Thread(massimAgent);		
		thread.start();
	}
	
	
	@Override
	public List<Literal> perceive() {
		ArrayList<Literal> result = null;
		synchronized(percepts) {
			result = new ArrayList<Literal>(percepts); // it must be a copy!
		}
		return result;
	}
	
	@Override
	public void act(ActionExec act, List<ActionExec> feedback) {
		super.act(act, feedback);

        if (act.getActionTerm().getFunctor().equals("go")) {
            massimAgent.setNextAction(act.getActionTerm().getTerm(0).toString());
//        } else if (act.getActionTerm().getFunctor().equals("get")) {
            
        } else {
        	System.err.println("("+getAgName()+"): ignoring action "+act+", unknow action.");
        }
     }	
	
	@Override
	public void broadcast(Message m) throws Exception {
		if (m.getPropCont() instanceof MessageContent) {
			massimAgent.broadcastMessage((MessageContent)m.getPropCont());
		} else {
			System.err.println("("+getAgName()+"): invalid message content - "+m.toString());
		}
	}

	@Override
	public void sendMsg(Message m) throws Exception {
		if (m.getPropCont() instanceof MessageContent) {
			massimAgent.sendMessage((MessageContent)m.getPropCont(), m.getReceiver());
		} else {
			System.err.println("("+getAgName()+"): invalid message content - "+m.toString());
		}
		
	}

	@Override
	public void checkMail() {
		super.checkMail();
	}
	
	public void onMessageReceived(MessageContent message) {
		synchronized (inbox) {
			inbox.addLast(message);
		}
	}
	
	public void onServerPerception(Element perception) {
//		System.out.println("onServerPerception: " + perception);
		ArrayList<Literal> seeList = new ArrayList<Literal>();
		
		
		int agx   = Integer.parseInt(perception.getAttribute("posx"));
		int agy   = Integer.parseInt(perception.getAttribute("posy"));
		int step  = Integer.parseInt(perception.getAttribute("step"));

		NodeList nl = perception.getChildNodes();
		//System.out.println("NL LENGTH="+nl.getLength());
		for (int i=0; i<nl.getLength(); i++) {
			Node n = nl.item(i);
			//System.out.println("NL LOCALNAME="+n.getNodeName());
			if (n.getNodeType() == Node.ELEMENT_NODE && "cell".equals(n.getNodeName())) {
				Element cell_element = (Element)n;
				
				int see_x = Integer.parseInt(cell_element.getAttribute("x"));
				int see_y = Integer.parseInt(cell_element.getAttribute("y"));
				String value = null;
				for (int j=0; j<cell_element.getChildNodes().getLength(); j++) {
					Node cell_child = cell_element.getChildNodes().item(j);
					if (cell_child.getNodeType() != Node.ELEMENT_NODE) continue;
					value = cell_child.getNodeName();
					if ("corral".equals(value)) {
						value += "_"+ ((Element)cell_child).getAttribute("type");
					}
					break;
				}
				seeList.add(createLiteral("see", createNumber(see_x), createNumber(see_y), createString(value), createNumber(step)));
			}
		}
		
		// add location in perception
		Literal mypos = createLiteral("mypos", createNumber(agx), createNumber(agy), createNumber(step));
		
		synchronized(percepts) {
			percepts.add(mypos);
			percepts.addAll(seeList);
		}
	}
	
	/** returns the number of the agent based on its name (the number in the end of the name, e.g. dummie9 ==> id = 8) */
    public static int getAgId(String agName) {
        boolean nbWith2Digits = Character.isDigit(agName.charAt(agName.length()-2));
        if (nbWith2Digits)
            return (Integer.parseInt(agName.substring(agName.length()-2))) -1;     
        else
            return (Integer.parseInt(agName.substring(agName.length()-1))) -1;    	
    }
    
	public AbstractAgent getMassimAgent() {
		return massimAgent;
	}

}
